pyDwell
==========================

This package contains a number of independent modules that are used by other packages.

It currently includes the following modules:

- constants : physical constants derived from NIST data
- fft : interfaces to scipy, anfft, fftw FFT packages that can deal with 2D data
- io : NetCDF interface to wrap functions in higher level code
- planck : Black body calculations and integrators
- rad : development tools, including a colored log package, function deprecation wrapper, file IO debugging wrapper
- smoothing : vector smoothing interface to scipy smoothing and kernels
- caselessdict : A case free dictionary
- testing: internal testing code.

Credits
-------

- Author: `Christopher Lee`_

.. _Christopher Lee: http://christopherlee.co.uk/
